diff --git a/core/modules/block/tests/src/Functional/BlockDemoTest.php b/core/modules/block/tests/src/Functional/BlockDemoTest.php
index d5dc7ba56dab657a28d3a1bce971b81edb480638..d9d1f519fbf24259b683324aedf46a82b0095b05 100644
--- a/core/modules/block/tests/src/Functional/BlockDemoTest.php
+++ b/core/modules/block/tests/src/Functional/BlockDemoTest.php
@@ -44,9 +44,8 @@ public function testBlockDemo() {
 
     // All available themes in core.
     $available_themes = [
-      'bartik',
       'olivero',
-      'seven',
+      'claro',
       'stark',
     ];
 
diff --git a/core/modules/block/tests/src/Functional/BlockTest.php b/core/modules/block/tests/src/Functional/BlockTest.php
index bec182bdd62d25cedcbc7112326e901c652d8124..336cd130e58fe788123064e1779f3abac8b1fef8 100644
--- a/core/modules/block/tests/src/Functional/BlockTest.php
+++ b/core/modules/block/tests/src/Functional/BlockTest.php
@@ -270,9 +270,8 @@ public function testBlock() {
   public function testBlockThemeSelector() {
     // Install all themes.
     $themes = [
-      'bartik',
       'olivero',
-      'seven',
+      'claro',
       'stark',
     ];
     \Drupal::service('theme_installer')->install($themes);
@@ -530,14 +529,14 @@ public function testUninstallTheme() {
     /** @var \Drupal\Core\Extension\ThemeInstallerInterface $theme_installer */
     $theme_installer = \Drupal::service('theme_installer');
 
-    $theme_installer->install(['seven']);
-    $this->config('system.theme')->set('default', 'seven')->save();
-    $block = $this->drupalPlaceBlock('system_powered_by_block', ['theme' => 'seven', 'region' => 'help']);
+    $theme_installer->install(['claro']);
+    $this->config('system.theme')->set('default', 'claro')->save();
+    $block = $this->drupalPlaceBlock('system_powered_by_block', ['theme' => 'claro', 'region' => 'help']);
     $this->drupalGet('<front>');
     $this->assertSession()->pageTextContains('Powered by Drupal');
 
     $this->config('system.theme')->set('default', 'stark')->save();
-    $theme_installer->uninstall(['seven']);
+    $theme_installer->uninstall(['claro']);
 
     // Ensure that the block configuration does not exist anymore.
     $this->assertNull(Block::load($block->id()));
diff --git a/core/modules/block/tests/src/FunctionalJavascript/BlockAddTest.php b/core/modules/block/tests/src/FunctionalJavascript/BlockAddTest.php
index aad92f24455aabc83adb8978279322b76767c01a..17e020d8cc86feaa3e875e75cb4451720c5ce4e8 100644
--- a/core/modules/block/tests/src/FunctionalJavascript/BlockAddTest.php
+++ b/core/modules/block/tests/src/FunctionalJavascript/BlockAddTest.php
@@ -28,7 +28,7 @@ class BlockAddTest extends WebDriverTestBase {
    * Tests the AJAX for the theme selector.
    */
   public function testBlockAddThemeSelector() {
-    \Drupal::service('theme_installer')->install(['seven']);
+    \Drupal::service('theme_installer')->install(['claro']);
 
     $this->drupalLogin($this->drupalCreateUser([
       'administer blocks',
@@ -37,7 +37,7 @@ public function testBlockAddThemeSelector() {
     $this->drupalGet('admin/structure/block/add/system_powered_by_block');
     $assert_session = $this->assertSession();
     // Pick a theme with a region that does not exist in another theme.
-    $assert_session->selectExists('Theme')->selectOption('seven');
+    $assert_session->selectExists('Theme')->selectOption('claro');
     $assert_session->assertWaitOnAjaxRequest();
     $assert_session->selectExists('Region')->selectOption('pre_content');
     $assert_session->assertWaitOnAjaxRequest();
diff --git a/core/modules/block/tests/src/Functional/BlockAdminThemeTest.php b/core/modules/block/tests/src/Functional/BlockAdminThemeTest.php
index 187cacf3a606c47e48899e8e5191bade509b5023..8559be7079ed303b407ffa70abf2dc6673a2f99d 100644
--- a/core/modules/block/tests/src/Functional/BlockAdminThemeTest.php
+++ b/core/modules/block/tests/src/Functional/BlockAdminThemeTest.php
@@ -36,22 +36,22 @@ public function testAdminTheme() {
 
     // Ensure that access to block admin page is denied when theme is not
     // installed.
-    $this->drupalGet('admin/structure/block/list/bartik');
+    $this->drupalGet('admin/structure/block/list/olivero');
     $this->assertSession()->statusCodeEquals(403);
 
     // Install admin theme and confirm that tab is accessible.
-    \Drupal::service('theme_installer')->install(['bartik']);
-    $edit['admin_theme'] = 'bartik';
+    \Drupal::service('theme_installer')->install(['olivero']);
+    $edit['admin_theme'] = 'olivero';
     $this->drupalGet('admin/appearance');
     $this->submitForm($edit, 'Save configuration');
-    $this->drupalGet('admin/structure/block/list/bartik');
+    $this->drupalGet('admin/structure/block/list/olivero');
     $this->assertSession()->statusCodeEquals(200);
   }
 
   /**
    * Ensure contextual links are disabled in Seven theme.
    */
-  public function testSevenAdminTheme() {
+  public function testClaroAdminTheme() {
     // Create administrative user.
     $admin_user = $this->drupalCreateUser([
       'access administration pages',
@@ -62,14 +62,14 @@ public function testSevenAdminTheme() {
     $this->drupalLogin($admin_user);
 
     // Install admin theme and confirm that tab is accessible.
-    \Drupal::service('theme_installer')->install(['seven']);
-    $edit['admin_theme'] = 'seven';
+    \Drupal::service('theme_installer')->install(['claro']);
+    $edit['admin_theme'] = 'claro';
     $this->drupalGet('admin/appearance');
     $this->submitForm($edit, 'Save configuration');
 
     // Define our block settings.
     $settings = [
-      'theme' => 'seven',
+      'theme' => 'claro',
       'region' => 'header',
     ];
 
@@ -36,22 +36,22 @@ public function testAdminTheme() {
 
   /**
-   * Ensure contextual links are disabled in Seven theme.
+   * Ensure contextual links are disabled in Claro theme.
    */
diff --git a/core/modules/block/tests/src/Functional/NonDefaultBlockAdminTest.php b/core/modules/block/tests/src/Functional/NonDefaultBlockAdminTest.php
index 7da71c9804eef9ceab115ec12dab4365f77eb7a0..dac5331fa1ef285f323d424b035594fd7137e277 100644
--- a/core/modules/block/tests/src/Functional/NonDefaultBlockAdminTest.php
+++ b/core/modules/block/tests/src/Functional/NonDefaultBlockAdminTest.php
@@ -41,11 +41,11 @@ public function testNonDefaultBlockAdmin() {
       'administer themes',
     ]);
     $this->drupalLogin($admin_user);
-    $new_theme = 'bartik';
+    $new_theme = 'olivero';
     \Drupal::service('theme_installer')->install([$new_theme]);
     // Ensure that the Bartik tab is shown.
     $this->drupalGet('admin/structure/block/list/' . $new_theme);
-    $this->assertSession()->pageTextContains('Bartik(active tab)');
+    $this->assertSession()->pageTextContains('Olivero(active tab)');
   }
 
 }
@@ -41,11 +41,11 @@ public function testNonDefaultBlockAdmin() {
     \Drupal::service('theme_installer')->install([$new_theme]);
-    // Ensure that the Bartik tab is shown.
+    // Ensure that the Olivero tab is shown.
     $this->drupalGet('admin/structure/block/list/' . $new_theme);